==> phosphorus-0.3.0.tar.gz: docs/README.md <==
# phosphorus: A dependency management and packaging tool

[![tests][test_badge]][test_url]
[![license][licence_badge]][licence_url]
[![pypi][pypi_badge]][pypi_url]
[![downloads][pepy_badge]][pepy_url]
[![code style: black][black_badge]][black_url]
[![build automation: yam][yam_badge]][yam_url]
[![Lint: ruff][ruff_badge]][ruff_url]

`phosphorus` is a dependency management and packaging tool replacement tool that's
been heavily influenced by [poetry][poetry]. The main goal of phosphorus is to have minimal
external dependencies, although some common packaging tools are required.

## Links

-   [Documentation]
-   [Changelog]

[test_badge]: https://github.com/spapanik/phosphorus/actions/workflows/tests.yml/badge.svg
[test_url]: https://github.com/spapanik/phosphorus/actions/workflows/tests.yml
[licence_badge]: https://img.shields.io/badge/license-LGPL_v3-blue.svg
[licence_url]: https://github.com/spapanik/phosphorus/blob/main/docs/LICENSE.md
[pypi_badge]: https://img.shields.io/pypi/v/phosphorus
[pypi_url]: https://pypi.org/project/phosphorus
[pepy_badge]: https://pepy.tech/badge/phosphorus
[pepy_url]: https://pepy.tech/project/phosphorus
[black_badge]: https://img.shields.io/badge/code_style-black-000000.svg
[black_url]: https://github.com/psf/black
[yam_badge]: https://img.shields.io/badge/build_automation-yamk-success
[yam_url]: https://github.com/spapanik/yamk
[ruff_badge]: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v1.json
[ruff_url]: https://github.com/charliermarsh/ruff
[Documentation]: https://phosphorus.readthedocs.io/en/stable/
[Changelog]: https://github.com/spapanik/phosphorus/blob/main/docs/CHANGELOG.md
[poetry]: https://python-poetry.org/

==> phosphorus-0.5.0.tar.gz: docs/README.md <==
# phosphorus: A dependency management and packaging tool

[![tests][test_badge]][test_url]
[![license][licence_badge]][licence_url]
[![pypi][pypi_badge]][pypi_url]
[![downloads][pepy_badge]][pepy_url]
[![code style: black][black_badge]][black_url]
[![build automation: yam][yam_badge]][yam_url]
[![Lint: ruff][ruff_badge]][ruff_url]

`phosphorus` is a dependency management and packaging tool replacement tool that's
been heavily influenced by [poetry][poetry]. The main goal of phosphorus is to have minimal
external dependencies, although some common packaging tools are required.

## Links

-   [Documentation]
-   [Changelog]

[test_badge]: https://github.com/spapanik/phosphorus/actions/workflows/tests.yml/badge.svg
[test_url]: https://github.com/spapanik/phosphorus/actions/workflows/tests.yml
[licence_badge]: https://img.shields.io/pypi/l/phosphorus
[licence_url]: https://github.com/spapanik/phosphorus/blob/main/docs/LICENSE.md
[pypi_badge]: https://img.shields.io/pypi/v/phosphorus
[pypi_url]: https://pypi.org/project/phosphorus
[pepy_badge]: https://pepy.tech/badge/phosphorus
[pepy_url]: https://pepy.tech/project/phosphorus
[black_badge]: https://img.shields.io/badge/code%20style-black-000000.svg
[black_url]: https://github.com/psf/black
[yam_badge]: https://img.shields.io/badge/build%20automation-yamk-success
[yam_url]: https://github.com/spapanik/yamk
[ruff_badge]: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v1.json
[ruff_url]: https://github.com/charliermarsh/ruff
[Documentation]: https://phosphorus.readthedocs.io/en/stable/
[Changelog]: https://github.com/spapanik/phosphorus/blob/main/docs/CHANGELOG.md
[poetry]: https://python-poetry.org/
